-- cPanel mysql backup
GRANT USAGE ON *.* TO 'mariuspe'@'192.168.1.%' IDENTIFIED BY PASSWORD '*ED0C886DF718F7330DA345A2A24E5FDE60C0782E';
GRANT ALL PRIVILEGES ON `mariuspe\_groparu`.* TO 'mariuspe'@'192.168.1.%';
GRANT ALL PRIVILEGES ON `mariuspe\_gllr1`.* TO 'mariuspe'@'192.168.1.%';
GRANT USAGE ON *.* TO 'mariuspe'@'193.203.204.226' IDENTIFIED BY PASSWORD '*ED0C886DF718F7330DA345A2A24E5FDE60C0782E';
GRANT ALL PRIVILEGES ON `mariuspe\_gllr1`.* TO 'mariuspe'@'193.203.204.226';
GRANT ALL PRIVILEGES ON `mariuspe\_groparu`.* TO 'mariuspe'@'193.203.204.226';
GRANT USAGE ON *.* TO 'mariuspe'@'core3.hostbase.net' IDENTIFIED BY PASSWORD '*ED0C886DF718F7330DA345A2A24E5FDE60C0782E';
GRANT ALL PRIVILEGES ON `mariuspe\_gllr1`.* TO 'mariuspe'@'core3.hostbase.net';
GRANT ALL PRIVILEGES ON `mariuspe\_groparu`.* TO 'mariuspe'@'core3.hostbase.net';
GRANT USAGE ON *.* TO 'mariuspe'@'localhost' IDENTIFIED BY PASSWORD '*ED0C886DF718F7330DA345A2A24E5FDE60C0782E';
GRANT ALL PRIVILEGES ON `mariuspe\_groparu`.* TO 'mariuspe'@'localhost';
GRANT ALL PRIVILEGES ON `mariuspe\_gllr1`.* TO 'mariuspe'@'localhost';
GRANT USAGE ON *.* TO 'mariuspe_gllr1'@'192.168.1.%' IDENTIFIED BY PASSWORD '*1CC20AB0687B03A2786527AD03AD12A6DE490D11';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `mariuspe\_gllr1`.* TO 'mariuspe_gllr1'@'192.168.1.%';
GRANT USAGE ON *.* TO 'mariuspe_gllr1'@'193.203.204.226' IDENTIFIED BY PASSWORD '*1CC20AB0687B03A2786527AD03AD12A6DE490D11';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `mariuspe\_gllr1`.* TO 'mariuspe_gllr1'@'193.203.204.226';
GRANT USAGE ON *.* TO 'mariuspe_gllr1'@'core3.hostbase.net' IDENTIFIED BY PASSWORD '*1CC20AB0687B03A2786527AD03AD12A6DE490D11';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `mariuspe\_gllr1`.* TO 'mariuspe_gllr1'@'core3.hostbase.net';
GRANT USAGE ON *.* TO 'mariuspe_gllr1'@'localhost' IDENTIFIED BY PASSWORD '*1CC20AB0687B03A2786527AD03AD12A6DE490D11';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, EXECUTE, CREATE VIEW, SHOW VIEW, CREATE ROUTINE, ALTER ROUTINE ON `mariuspe\_gllr1`.* TO 'mariuspe_gllr1'@'localhost';
GRANT USAGE ON *.* TO 'mariuspe_groparu'@'192.168.1.%' IDENTIFIED BY PASSWORD '*BFC6F1B218D4D69A6788C00642A4E14B02432360';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, CREATE ROUTINE ON `mariuspe\_groparu`.* TO 'mariuspe_groparu'@'192.168.1.%';
GRANT USAGE ON *.* TO 'mariuspe_groparu'@'193.203.204.226' IDENTIFIED BY PASSWORD '*BFC6F1B218D4D69A6788C00642A4E14B02432360';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, CREATE ROUTINE ON `mariuspe\_groparu`.* TO 'mariuspe_groparu'@'193.203.204.226';
GRANT USAGE ON *.* TO 'mariuspe_groparu'@'core3.hostbase.net' IDENTIFIED BY PASSWORD '*BFC6F1B218D4D69A6788C00642A4E14B02432360';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, CREATE ROUTINE ON `mariuspe\_groparu`.* TO 'mariuspe_groparu'@'core3.hostbase.net';
GRANT USAGE ON *.* TO 'mariuspe_groparu'@'localhost' IDENTIFIED BY PASSWORD '*BFC6F1B218D4D69A6788C00642A4E14B02432360';
GRANT SELECT, INSERT, UPDATE, DELETE, CREATE, DROP, REFERENCES, INDEX, ALTER, CREATE TEMPORARY TABLES, LOCK TABLES, CREATE ROUTINE ON `mariuspe\_groparu`.* TO 'mariuspe_groparu'@'localhost';
